@@ -2,8 +2,6 @@
 
 #  Cdnfundlibrary.pm
 #
-#  Version 0.6 retrieve more data via different fundlibrary.com url
-#  Version 0.5 made functional again
 #  Version 0.4 fixed up multiple lookup  (March 3, 2001)
 #  Version 0.3 fixed up yield lookup
 #  Version 0.2 functional with Finance::Quote - added error-checking
@@ -15,36 +13,30 @@ require 5.004;
 
 use strict;
 
-use vars qw( $FUNDLIB_URL $FUNDLIB_MAIN_URL);
+use vars qw($VERSION $FUNDLIB_URL $FUNDLIB_MAIN_URL);
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TableExtract;
-use JSON;
 
-use warnings;
-use Time::Piece;
-
-our $VERSION = '1.59_01'; #TRIAL VERSION
+$VERSION = '0.2';
 
 # URLs of where to obtain information.
 
 $FUNDLIB_URL =
-("https://www.fundlibrary.com/MutualFunds/GetFundSearchResults?cifscCategoryId=0&fundCompanyId=0&fundTypeId=0&isGradeA=true&isGradeB=true&isGradeC=true&isGradeD=true&isGradeE=true&sortBy=Default&page=0&searchText=");
+("http://www.fundlibrary.com/FundCard/FundCard_TFL.cfm?FundID=");
 $FUNDLIB_MAIN_URL=("http://www.fundlibrary.com");
 
 sub methods { return (canadamutual => \&fundlibrary,
                        fundlibrary => \&fundlibrary); }
 
 {
-    my @labels = qw/method source link name currency last date isodate nav yield
-        price net p_change/;
+    my @labels = qw/method source link name currency last date nav yield
+price/;
     sub labels { return (canadamutual => \@labels,
                           fundlibrary => \@labels); }
 }
 
-sub  trim { my $s = shift; $s =~ s/^\s+|\s+$//g; return $s };
-
 #
 # =======================================================================
 
@@ -52,86 +44,91 @@ sub fundlibrary   {
     my $quoter = shift;
     my @symbols = @_;
 
-    # Make sure symbols are requested
+    # Make sure symbols are requested  
     ##CAN exit more gracefully - add later##
 
     return unless @symbols;
 
     # Local Variables
     my(%fundquote, $mutual);
-    my($ua, $url, $reply, $ts, $row, $rowhd, $te, @rows, @ts);
+    my($ua, $url, $reply, $ts, $row, $rowhd, $te);
+#    my $te = new HTML::TableExtract();
 
     $ua = $quoter->user_agent;
 
     foreach (@symbols) {
 
       $mutual = $_;
-
       $url = "$FUNDLIB_URL$mutual";
       $reply = $ua->request(GET $url);
+      $te = new HTML::TableExtract();
 
-      $te = new HTML::TableExtract(headers => ["NAVPS"],
-           slice_columns => 0);
-
-      # Make sure something is returned  ##CAN exit more gracefully - add later##
+      # Make sure something is returned  ##CAN exit more gracefully -
+add later##
       return unless ($reply->is_success);
 
-      my $json = JSON->new;
-      my $data = decode_json($reply->decoded_content);
+      $te->parse($reply->content);
 
-#     If the fund is not found, "PriceAsOfDateString" is "0001-01-01T00:00"
-      if ( $$data{'PriceAsOfDateString'} eq "0001-01-01T00:00" )
-      {
-          $fundquote {$mutual,"success"} = 0;
-          $fundquote {$mutual,"errormsg"} = "Fund name $mutual not found";
-          next;
-      }
+      # Fund name
+      $ts = $te->table_state(0,1);
+      if($ts) {
+          ($row) = $ts->rows;
+          $fundquote {$mutual, "name"} = $$row[0];
 
-      my $t = Time::Piece->strptime($$data{'PriceAsOfDateString'}, "%Y-%m-%dT%T");
+          $fundquote {$mutual, "currency"} = "CAD";
+          $fundquote {$mutual, "source"} = $FUNDLIB_MAIN_URL;
+          $fundquote {$mutual, "link"} = $url;
+          $fundquote {$mutual, "method"} = "fundlibrary";
 
-      $te->parse($$data{'SearchFundResultView'});
+          # Fund price and date
+          $ts = $te->table_state(2,1);
+          ($row) = $ts->rows;
+          if ($$row[1] =~ /^\$.+as of/) {
+              $$row[1] =~ /(\d+\.\d+)/g;
+              $fundquote {$mutual, "price"} =  $1;
+              $fundquote {$mutual, "nav"} = $1;
+              $fundquote {$mutual, "last"} = $1;
 
-      # Check for a page without tables
-      # This gets returned when a bad symbol name is given
-      unless ( $te->tables > 0 )
-      {
-        $fundquote {$mutual,"success"} = 0;
-        $fundquote {$mutual,"errormsg"} = "Fund name $mutual not found";
-        next;
-      }
+              $$row[1] =~ /(\w+) (\d{1,2})\, (\d{4})/g;
+              $fundquote {$mutual, "date"} =  $1.' '.$2.', '.$3;
+          }
+          else {
+              $fundquote {$mutual, "success"} = 0;
+              $fundquote {$mutual, "errormsg"} = "Parse error retrieving
+price and date";
+          }
 
-      @rows = $te->rows;
-      if(@rows) {
-        $row = $rows[1];
+          # Performance yield
+          ### Fix up by looking for headers instead
 
-        $fundquote {$mutual, "name"} = trim($$row[0]);
-        $fundquote {$mutual, "symbol"} = $mutual;
-        $fundquote {$mutual, "currency"} = "CAD";
-        $fundquote {$mutual, "source"} = $FUNDLIB_MAIN_URL;
-        $fundquote {$mutual, "link"} = $url;
-        $fundquote {$mutual, "method"} = "fundlibrary";
-
-        # Fund price and date
-
-        $fundquote {$mutual, "price"} =  trim($$row[2]);
-        $fundquote {$mutual, "nav"} = trim($$row[2]);
-        $fundquote {$mutual, "last"} = trim($$row[2]);
-        $fundquote {$mutual, "net"} = trim($$row[3]);
-        $fundquote {$mutual, "p_change"} = trim($$row[4]);
-
-        $quoter->store_date(\%fundquote, $mutual, {usdate => $t->strftime("%m-%d-%Y")});
-
-        # Assume things are fine here.
-        $fundquote {$mutual, "success"} = 1;
-
-        # Performance yield
-        $fundquote {$mutual, "yield"} = trim($$row[5]) if ($$row[5] ne "--");
+          $ts = $te->table_state(2,3);
+          ($rowhd, $row) = $ts->rows;
+          if ($rowhd && $row) {
+              if ($$row[1] =~ /%/ && $$rowhd[1] =~ /Performance/) {
+                  $$row[1] =~ s/ //g;
+                  $fundquote {$mutual, "yield"} = $$row[1];
+              }
+          }
+          else {
+              $ts = $te->table_state(2,4);
+              ($rowhd, $row) = $ts->rows;
+              if ($rowhd && $row) {
+                  if ($$row[1] =~ /%/ && $$rowhd[1] =~ /Performance/) {
+                      $$row[1] =~ s/ //g;
+                      $fundquote {$mutual, "yield"} = $$row[1];
+                  }
+              }
+              else {
+                  $fundquote {$mutual, "yield"} = "NA";
+              }
+          }
       }
       else {
-        $fundquote {$mutual, "success"} = 0;
-        $fundquote {$mutual, "errormsg"} = "Fund Not Found";
+          $fundquote {$mutual, "success"} = 0;
+          $fundquote {$mutual, "errormsg"} = "Fund Not Found";
       }
 
+
    } #end symbols
 
    return %fundquote if wantarray;
@@ -192,3 +189,4 @@ Fundlibrary website - http://www.fundlibrary.com/
 Finance::Quote
 
 =cut
+
