@@ -38,12 +38,28 @@ use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
 use vars qw($VERSION $YAHOO_ASIA_URL);
 
-$VERSION = '1.13_02';
+$VERSION = '1.00';
 
 # URLs of where to obtain information.
 
 $YAHOO_ASIA_URL = ("http://sg.finance.yahoo.com/d/quotes.csv");
 
+# Each stock comes back in its own currency, or so it seems.
+my %currency_tags = (
+	SI => "SGD",
+	BO => "INR",
+	JK => "IDR",
+	HK => "HKD",
+	NS => "INR",
+	KS => "KRW",
+	KL => "MYR",
+	NZ => "NZD",
+	SS => "CNY",
+	SZ => "CNY",
+	TW => "TWD",
+	TH => "THB"
+);
+
 sub methods {return (asia => \&yahoo_asia,yahoo_asia => \&yahoo_asia)};
 
 {
@@ -64,8 +80,18 @@ sub yahoo_asia
 	my %info = yahoo_request($quoter,$YAHOO_ASIA_URL,\@symbols);
 
 	foreach my $symbol (@symbols) {
-		next unless $info{$symbol,"success"};
-		$info{$symbol,"method"} = "yahoo_asia";
+		if ($info{$symbol,"success"}) {
+			$info{$symbol,"method"} = "yahoo_asia";
+
+			# Symbols starting with a hat are always
+			# indexes, so they don't have a currency.
+			if (substr($symbol,0,1) eq "^") {
+				$info{$symbol,"currency"} = undef;
+			} else {
+				my ($exchange) = $symbol =~ /\.([A-Z]{2})$/;
+				$info{$symbol,"currency"} = $currency_tags{$exchange};
+			}
+		}
 	}
 
 	return %info if wantarray;
